@@ -4,7 +4,6 @@ import traceback
 
 from os.path import expandvars, expanduser, abspath
 from fireworks.core.firework import FireTaskBase
-from fireworks.utilities.fw_serializers import FWSerializable
 
 __author__ = 'Anubhav Jain, David Waroquiers, Shyue Ping Ong'
 __copyright__ = 'Copyright 2013, The Materials Project'
@@ -14,7 +13,7 @@ __email__ = 'ongsp@ucsd.edu'
 __date__ = 'Jan 6, 2014'
 
 
-class FileWriteTask(FireTaskBase, FWSerializable):
+class FileWriteTask(FireTaskBase):
     """
     A FireTask to write files:
     Required params:
@@ -31,7 +30,7 @@ class FileWriteTask(FireTaskBase, FWSerializable):
                 f.write(d["contents"])
 
 
-class FileDeleteTask(FireTaskBase, FWSerializable):
+class FileDeleteTask(FireTaskBase):
     """
     A FireTask to delete files:
     Required params:
@@ -48,7 +47,7 @@ class FileDeleteTask(FireTaskBase, FWSerializable):
             os.remove(os.path.join(pth, f))
 
 
-class FileTransferTask(FireTaskBase, FWSerializable):
+class FileTransferTask(FireTaskBase):
     """
     A FireTask to Transfer files:
     Required params:
@@ -87,10 +86,10 @@ class FileTransferTask(FireTaskBase, FWSerializable):
 
         for f in self["files"]:
             try:
-                src = abspath(expanduser(expandvars(f['src']))) if shell_interpret else f['src']
+                src = abspath(expanduser(expandvars(f))) if shell_interpret else f
 
                 if mode == 'rtransfer':
-                    dest = f['dest']
+                    dest = self['dest']
                     if os.path.isdir(src):
                         if not self._rexists(sftp, dest):
                             sftp.mkdir(dest)
@@ -102,7 +101,8 @@ class FileTransferTask(FireTaskBase, FWSerializable):
                         sftp.put(src, dest)
 
                 else:
-                    dest = abspath(expanduser(expandvars(f['dest']))) if shell_interpret else f['dest']
+                    dest = abspath(expanduser(expandvars(self['dest']))) if \
+                        shell_interpret else self['dest']
                     FileTransferTask.fn_list[mode](src, dest)
 
             except:
@@ -110,7 +110,7 @@ class FileTransferTask(FireTaskBase, FWSerializable):
                 if not ignore_errors:
                     raise ValueError(
                         "There was an error performing operation {} from {} "
-                        "to {}".format(mode, src, dest))
+                        "to {}".format(mode, self["files"], self["dest"]))
         if mode == 'rtransfer':
             sftp.close()
             ssh.close()
